==> nextcloud-19.0.8.tgz: nextcloud/apps/files_sharing/l10n/es_EC.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Compartido contigo",
    "Nothing shared with you yet" : "Nada ha sido compartido contigo aún",
    "Files and folders others share with you will show up here" : "Los archivos y carpetas que sean compartidos contigo se mostrarán aquí",
    "Shared with others" : "Compartido con otros",
    "Nothing shared yet" : "Nada compartido aún",
    "Files and folders you share will show up here" : "Los archivos y carpetas que compartas se mostrarán aquí",
    "Shared by link" : "Compartido mediante enlace",
    "No shared links" : "No hay enlaces compartidos",
    "Files and folders you share by link will show up here" : "Los archivos y carpetas que compartas mediante enlaces se mostrarán aquí",
    "Shares" : "Elementos compartidos",
    "Restore" : "Restaurar",
    "error" : "error",
    "Move or copy" : "Mover o copiar",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "You can upload into this folder" : "Puedes cargar archivos dentro de esta carpeta",
    "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
    "Invalid server URL" : "URL del servidor inválido",
    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el enlace público a tu Nextcloud",
    "No expiration date set" : "No se ha establecido la fecha de expiración",
    "Shared by" : "Compartido por",
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado mediante un enlace público",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante un enlace público",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group {group}" : "Compartido con el gupo {group}",
    "Removed share for group {group}" : "Se eliminó el elemento compartido del grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "{actor} removed share for group {group}" : "{actor} eliminó el elemento compartido del grupo {group}",
    "You shared {file} with group {group}" : "Compartiste {file} con el grupo {group}",
    "You removed group {group} from {file}" : "Eliminaste al grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} eliminó el grupo {group} de {file}",
    "Shared as public link" : "Compartido como un enlace público",
    "Removed public link" : "Enlace público eliminado",
    "Public link expired" : "El enlace público ha caducado",
    "{actor} shared as public link" : "{actor} compartió como un enlace público",
    "{actor} removed public link" : "{actor} eliminó el enlace público",
    "Public link of {actor} expired" : "El enlace público de {actor} ha caducado",
    "You shared {file} as public link" : "Compartiste {file} como un enlace público",
    "You removed public link for {file}" : "Eliminaste el enlace público de {file}",
    "Public link expired for {file}" : "El enlace público para {file} ha caducado",
    "{actor} shared {file} as public link" : "{actor} ha compartido {file} como un enlace público",
    "{actor} removed public link for {file}" : "{actor} eliminó el enlace público de {file}",
    "Public link of {actor} for {file} expired" : "El enlace público de {actor} para {file} ha caducado",
    "{user} accepted the remote share" : "{user} aceptó el elemento compartido remoto",
    "{user} declined the remote share" : "{user} declinó el elemento compartido remoto",
    "You received a new remote share {file} from {user}" : "Recibiste un nuevo elemento compartido remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptó el elemento compartido remoto de {file}",
    "{user} declined the remote share of {file}" : "{user} declinó el elemento compartido remoto de {file}",
    "{user} unshared {file} from you" : "{user} ha dejado de compartir {file} contigo",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Se eliminó el elemento compartido para {user}",
    "{actor} removed themselves" : "{actor} se ha eliminado",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "{actor} removed share for {user}" : "{actor} eliminó el elemento compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} eliminó el elemento compartido",
    "You shared {file} with {user}" : "Compartiste {file} con {user}",
    "You removed {user} from {file}" : "Eliminaste a {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartió {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} ha compartido {file} contigo",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta comparitdo por correo o por enlace público ha sido <strong>descargado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
    "Files" : "Archivos",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
    "Could not delete share" : "No fue posible borrar el elemento compartido",
    "Please specify a file or folder path" : "Por favor especifica un archivo o ruta de carpeta",
    "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el correo / carpeta no existe ",
    "Could not create share" : "No fue posible crear el elemento compartido",
    "invalid permissions" : "permisos inválidos",
    "Please specify a valid user" : "Por favor especifica un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupos está deshabilitado por el administrador",
    "Please specify a valid group" : "Por favor especifica un grupo válido",
    "Public link sharing is disabled by the administrator" : "Compartir enlaces públicos está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "Cargas públicas deshabilitadas por el administrador",
    "Public upload is only possible for publicly shared folders" : "Las cargas públicas son posibles sólo para carpetas compartidas públicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "No puedes compartir al Círculo si la aplicación no está habilitada",
    "Please specify a valid circle" : "Por favor especifica un círculo válido",
    "Unknown share type" : "Tipo de elemento compartido desconocido",
    "Not a directory" : "No es una carpeta",
    "Could not lock path" : "No fue posible bloquear la ruta",
    "Wrong or no update parameter given" : "El parametro de actualización está erróneo o falta",
    "Can't change permissions for public share links" : "No es posible cambiar los permisos para enlaces  públicos compartidos",
    "shared by %s" : "compartido por %s",
    "Direct link" : "Enlace directo",
    "Add to your Nextcloud" : "Agregar a tu Nextcloud",
    "Share API is disabled" : "El API para compartir está deshabilitado",
    "File sharing" : "Compartir archivos",
    "Accept" : "Aceptar",
    "Sharing" : "Compartiendo",
    "Allow editing" : "Permitir edición",
    "Allow resharing" : "Permitir volver a compartir",
    "Set expiration date" : "Establecer fecha de expiración",
    "Unshare" : "Dejar de compartir",
    "group" : "grupo",
    "remote" : "remoto",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingresa una contraseña",
    "Cancel" : "Cancelar",
    "Read only" : "Sólo lectura",
    "Allow upload and editing" : "Permitir carga y edición",
    "File drop (upload only)" : "Permitir carga",
    "Password protect" : "Proteger con contraseña",
    "Add another link" : "Agregar otro enlace",
    "Share link" : "Compartir enlace",
    "Resharing is not allowed" : "No se permite volver a compartir",
    "Shared" : "Compartido",
    "Share" : "Compartir",
    "Shared with" : "Compartido con",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y con el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Compartido desde",
    "Expiration date" : "Fecha de expiración",
    "Sorry, this link doesn’t seem to work anymore." : "Lo sentimos, parece que este enlace ya no funciona. ",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace caducó",
    "sharing is disabled" : "compartir está deshabilitado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió este enlace.",
    "Share note" : "Compartir nota",
    "Download %s" : "Descargar %s",
    "Upload files to %s" : "Cargar archivos a %s",
    "Select or drop files" : "Selecciona o suelta los archivos",
    "Uploaded files:" : "Archivos cargados:",
    "Uploading files…" : "Cargando archivos..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.10.tgz: nextcloud/apps/files_sharing/l10n/es_EC.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Compartido contigo",
    "Nothing shared with you yet" : "Nada ha sido compartido contigo aún",
    "Files and folders others share with you will show up here" : "Los archivos y carpetas que sean compartidos contigo se mostrarán aquí",
    "Shared with others" : "Compartido con otros",
    "Nothing shared yet" : "Nada compartido aún",
    "Files and folders you share will show up here" : "Los archivos y carpetas que compartas se mostrarán aquí",
    "Shared by link" : "Compartido mediante enlace",
    "No shared links" : "No hay enlaces compartidos",
    "Files and folders you share by link will show up here" : "Los archivos y carpetas que compartas mediante enlaces se mostrarán aquí",
    "Shares" : "Elementos compartidos",
    "Restore" : "Restaurar",
    "error" : "error",
    "Move or copy" : "Mover o copiar",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "You can upload into this folder" : "Puedes cargar archivos dentro de esta carpeta",
    "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
    "Invalid server URL" : "URL del servidor inválido",
    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el enlace público a tu Nextcloud",
    "No expiration date set" : "No se ha establecido la fecha de expiración",
    "Shared by" : "Compartido por",
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado mediante un enlace público",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante un enlace público",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group {group}" : "Compartido con el gupo {group}",
    "Removed share for group {group}" : "Se eliminó el elemento compartido del grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "{actor} removed share for group {group}" : "{actor} eliminó el elemento compartido del grupo {group}",
    "You shared {file} with group {group}" : "Compartiste {file} con el grupo {group}",
    "You removed group {group} from {file}" : "Eliminaste al grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} eliminó el grupo {group} de {file}",
    "Shared as public link" : "Compartido como un enlace público",
    "Removed public link" : "Enlace público eliminado",
    "Public link expired" : "El enlace público ha caducado",
    "{actor} shared as public link" : "{actor} compartió como un enlace público",
    "{actor} removed public link" : "{actor} eliminó el enlace público",
    "Public link of {actor} expired" : "El enlace público de {actor} ha caducado",
    "You shared {file} as public link" : "Compartiste {file} como un enlace público",
    "You removed public link for {file}" : "Eliminaste el enlace público de {file}",
    "Public link expired for {file}" : "El enlace público para {file} ha caducado",
    "{actor} shared {file} as public link" : "{actor} ha compartido {file} como un enlace público",
    "{actor} removed public link for {file}" : "{actor} eliminó el enlace público de {file}",
    "Public link of {actor} for {file} expired" : "El enlace público de {actor} para {file} ha caducado",
    "{user} accepted the remote share" : "{user} aceptó el elemento compartido remoto",
    "{user} declined the remote share" : "{user} declinó el elemento compartido remoto",
    "You received a new remote share {file} from {user}" : "Recibiste un nuevo elemento compartido remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptó el elemento compartido remoto de {file}",
    "{user} declined the remote share of {file}" : "{user} declinó el elemento compartido remoto de {file}",
    "{user} unshared {file} from you" : "{user} ha dejado de compartir {file} contigo",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Se eliminó el elemento compartido para {user}",
    "{actor} removed themselves" : "{actor} se ha eliminado",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "{actor} removed share for {user}" : "{actor} eliminó el elemento compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} eliminó el elemento compartido",
    "You shared {file} with {user}" : "Compartiste {file} con {user}",
    "You removed {user} from {file}" : "Eliminaste a {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartió {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} ha compartido {file} contigo",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta comparitdo por correo o por enlace público ha sido <strong>descargado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
    "Files" : "Archivos",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
    "Could not delete share" : "No fue posible borrar el elemento compartido",
    "Please specify a file or folder path" : "Por favor especifica un archivo o ruta de carpeta",
    "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el archivo/carpeta no existe",
    "Could not create share" : "No fue posible crear el elemento compartido",
    "Please specify a valid user" : "Por favor especifica un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupos está deshabilitado por el administrador",
    "Please specify a valid group" : "Por favor especifica un grupo válido",
    "Public link sharing is disabled by the administrator" : "Compartir enlaces públicos está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "Cargas públicas deshabilitadas por el administrador",
    "Public upload is only possible for publicly shared folders" : "Las cargas públicas son posibles sólo para carpetas compartidas públicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "No puedes compartir al Círculo si la aplicación no está habilitada",
    "Please specify a valid circle" : "Por favor especifica un círculo válido",
    "Unknown share type" : "Tipo de elemento compartido desconocido",
    "Not a directory" : "No es una carpeta",
    "Could not lock path" : "No fue posible bloquear la ruta",
    "Wrong or no update parameter given" : "El parametro de actualización está erróneo o falta",
    "Can't change permissions for public share links" : "No es posible cambiar los permisos para enlaces  públicos compartidos",
    "shared by %s" : "compartido por %s",
    "Direct link" : "Enlace directo",
    "Add to your Nextcloud" : "Agregar a tu Nextcloud",
    "Share API is disabled" : "El API para compartir está deshabilitado",
    "File sharing" : "Compartir archivos",
    "Accept" : "Aceptar",
    "Sharing" : "Compartiendo",
    "Allow editing" : "Permitir edición",
    "Allow resharing" : "Permitir volver a compartir",
    "Set expiration date" : "Establecer fecha de expiración",
    "Unshare" : "Dejar de compartir",
    "group" : "grupo",
    "remote" : "remoto",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingresa una contraseña",
    "Cancel" : "Cancelar",
    "Read only" : "Sólo lectura",
    "Allow upload and editing" : "Permitir carga y edición",
    "File drop (upload only)" : "Permitir carga",
    "Password protect" : "Proteger con contraseña",
    "Add another link" : "Agregar otro enlace",
    "Share link" : "Compartir enlace",
    "Resharing is not allowed" : "No se permite volver a compartir",
    "Shared" : "Compartido",
    "Share" : "Compartir",
    "Shared with" : "Compartido con",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y con el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Compartido desde",
    "Expiration date" : "Fecha de expiración",
    "Sorry, this link doesn’t seem to work anymore." : "Lo sentimos, parece que este enlace ya no funciona. ",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace caducó",
    "sharing is disabled" : "compartir está deshabilitado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió este enlace.",
    "Share note" : "Compartir nota",
    "Download %s" : "Descargar %s",
    "Upload files to %s" : "Cargar archivos a %s",
    "Select or drop files" : "Selecciona o suelta los archivos",
    "Uploaded files:" : "Archivos cargados:",
    "invalid permissions" : "permisos inválidos"
},
"nplurals=2; plural=(n != 1);");
